--------------------------------------------------------------------------------
-- system_stub.vhd
--------------------------------------------------------------------------------
library ieee;   use ieee.std_logic_1164.all;
library unisim; use unisim.vcomponents.all;

entity usb_macro is
	port (
		-- usb connections
		usb_vp : in std_logic;
		usb_vpo : out std_logic;
		rstn : in std_logic;
		usb_fse0 : out std_logic;
		usb_oe : out std_logic;
		usb_vm : in std_logic;

		-- Expansion connector
		clk_a1: in  std_logic;             -- osc
		iop_a1: out std_logic;             -- SEG_E
		ion_a1: out std_logic;             -- SEG_D
		iop_a2: out std_logic;             -- SEG_C
		ion_a2: out std_logic;             -- SEG_DP
		iop_a3: out std_logic;             -- SEG_B
		ion_a3: out std_logic;             -- SEG_A
		iop_a4: out std_logic;             -- SEG_F
		ion_a4: out std_logic;             -- SEG_G
		iop_a5: in  std_logic;             -- C_PB
		ion_a5: in  std_logic;             -- C_SW
		iop_a6: out std_logic;             -- MUX_A
		ion_a6: out std_logic;             -- MUX_B
		iop_b1: out std_logic;             -- MUX_C
		iop_b4: out std_logic;             -- /vsync
		ion_b4: out std_logic;             -- /hsync
		iop_b5: out std_logic;             -- blue
		ion_b5: out std_logic;             -- green
		iop_b6: out std_logic;             -- red
		ion_b6: out std_logic              -- bright
	);
end usb_macro;

architecture imp of usb_macro is
	--------------------------------------------------------------------------------
	component system is
		port (
			usb_vm:     in std_logic;
			usb_vp:     in std_logic;
			usb_fse0:   out std_logic;
			usb_oe:     out std_logic;
			rstn:       in std_logic;
			usb_vpo:    out std_logic;
			usb_iii:    in std_logic_vector(15 downto 0);
			clk48:      in std_logic;
			usb_ooo:    out std_logic_vector(15 downto 0);
			usb_con_o:  out std_logic;
			usb_con_i:  in std_logic;
			usb_con_t:  out std_logic
		);
	end component;
	--------------------------------------------------------------------------------
	component tebl is
		port (
			clk48:   out std_logic;                     -- 48mhz clock (usb)
			clk25:  out std_logic;                     -- 25mhz clock (vga)
			pb:     out std_logic_vector(7 downto 0);  -- push buttons
			sw:     out std_logic_vector(7 downto 0);  -- dip switches
			led:    in  std_logic_vector(7 downto 0);  -- leds
			disp:   in  std_logic_vector(15 downto 0); -- 7-segment displays
			vr:     in  std_logic;                     -- vga red
			vg:     in  std_logic;                     -- vga green
			vb:     in  std_logic;                     -- vga blue
			vi:     in  std_logic;                     -- vga intensity
			vcol:   out std_logic_vector(9 downto 0);  -- vga column
			vrow:   out std_logic_vector(9 downto 0);  -- vga row
			vvblk:  out std_logic;                     -- vga vertical blanking
			vhblk:  out std_logic;                     -- vga horizontal blanking
			----------------------------               --
			clk_a1: in  std_logic;                     -- osc
			iop_a1: out std_logic;                     -- seg_e
			ion_a1: out std_logic;                     -- seg_d
			iop_a2: out std_logic;                     -- seg_c
			ion_a2: out std_logic;                     -- seg_dp
			iop_a3: out std_logic;                     -- seg_b
			ion_a3: out std_logic;                     -- seg_a
			iop_a4: out std_logic;                     -- seg_f
			ion_a4: out std_logic;                     -- seg_g
			iop_a5: in  std_logic;                     -- c_pb
			ion_a5: in  std_logic;                     -- c_sw
			iop_a6: out std_logic;                     -- mux_a
			ion_a6: out std_logic;                     -- mux_b
			iop_b1: out std_logic;                     -- mux_c
			iop_b4: out std_logic;                     -- /vsync
			ion_b4: out std_logic;                     -- /hsync
			iop_b5: out std_logic;                     -- blue
			ion_b5: out std_logic;                     -- green
			iop_b6: out std_logic;                     -- red
			ion_b6: out std_logic                      -- bright
		);
	end component;
	--------------------------------------------------------------------------------
	signal input_port:  std_logic_vector (15 downto 0);
	signal output_port: std_logic_vector (15 downto 0);
	signal pb_port:     std_logic_vector (7 downto 0);
	signal sw_port:     std_logic_vector (7 downto 0);
	signal clk_a1_i:    std_logic;
	signal clk48:       std_logic;
	--------------------------------------------------------------------------------
	begin
		--------------------------------------------------------------------------------
		uusb : system
		port map (
			usb_vm    => usb_vm,
			usb_vp    => usb_vp,
			usb_fse0  => usb_fse0,
			usb_oe    => usb_oe,
			rstn      => rstn,
			usb_vpo   => usb_vpo,
			usb_iii   => input_port,
			clk48     => clk48,
			usb_ooo   => output_port,
			usb_con_o => open,
			usb_con_i => '0',
			usb_con_t => open
		);
		--------------------------------------------------------------------------------
		ubuf48 : bufg port map (
			i=> clk_a1,
			o=> clk_a1_i);
		--clk_a1_i <= clk_a1;
		--------------------------------------------------------------------------------
		utebl : tebl
		port map (
			clk48  => clk48,
			clk25  => open,
			pb     => pb_port,
			sw     => sw_port,
			led    => sw_port,
			disp   => output_port,
			vr     => '0',
			vg     => '0', 
			vb     => '0', 
			vi     => '0',
			vcol   => open,
			vrow   => open,
			vvblk  => open,
			vhblk  => open,
			clk_a1 => clk_a1_i,
			iop_a1 => iop_a1,
			ion_a1 => ion_a1,
			iop_a2 => iop_a2,
			ion_a2 => ion_a2,
			iop_a3 => iop_a3,
			ion_a3 => ion_a3,
			iop_a4 => iop_a4,
			ion_a4 => ion_a4,
			iop_a5 => iop_a5,
			ion_a5 => ion_a5,
			iop_a6 => iop_a6,
			ion_a6 => ion_a6,
			iop_b1 => iop_b1,
			iop_b4 => iop_b4,
			ion_b4 => ion_b4,
			iop_b5 => iop_b5,
			ion_b5 => ion_b5,
			iop_b6 => iop_b6,
			ion_b6 => ion_b6
		);

	input_port <= pb_port & sw_port;

end architecture imp;
